﻿//
// Copyright (c) 2015, MindFusion LLC - Bulgaria.
//

using System;
using System.Windows;
using System.Linq;

using MindFusion.Reporting;


namespace MindFusion.Reporting.Wpf.Samples.CS.Invoices
{
	/// <summary>
	/// Interaction logic for MainWindow.xaml
	/// </summary>
	public partial class MainWindow : Window
	{
		public MainWindow()
		{
			InitializeComponent();

			nwindDataSet dataSet = new nwindDataSet();
			nwindDataSetTableAdapters.OrdersTableAdapter ordersAdapter =
				new Invoices.nwindDataSetTableAdapters.OrdersTableAdapter();
			ordersAdapter.Fill(dataSet.Orders);
			nwindDataSetTableAdapters.InvoicesTableAdapter invoicesAdapter =
				new Invoices.nwindDataSetTableAdapters.InvoicesTableAdapter();
			invoicesAdapter.Fill(dataSet.Invoices);
			nwindDataSetTableAdapters.CustomersTableAdapter customersAdapter =
				new Invoices.nwindDataSetTableAdapters.CustomersTableAdapter();
			customersAdapter.Fill(dataSet.Customers);

			nwindDataSet.CustomersDataTable customerData = customersAdapter.GetData();
			nwindDataSet.InvoicesDataTable invoiceData = invoicesAdapter.GetData();

			Report report = Report.FromDictionary(new Uri("InvoicesReport.xaml", UriKind.Relative), "invoices");
			report.DataContext = dataSet;
			report.QueryDetails += (s, e) =>
				{
					DataRange sender = s as DataRange;
					if (sender != null)
					{
						if (sender.Name == "BillingRange")
						{
							nwindDataSet.OrdersRow orderRow = e.MasterRow as nwindDataSet.OrdersRow;

							e.Details = customerData.
								Where(customer => customer.CustomerID == orderRow.CustomerID);
						}
						else if (sender.Name == "OrderDetailsRange")
						{
							nwindDataSet.OrdersRow orderRow = e.MasterRow as nwindDataSet.OrdersRow;

							e.Details = invoiceData.
								Where(invoice => invoice.OrderID == orderRow.OrderID);
						}
					}
				};
			report.Run();

			ReportLayout layout = report.Layout(new Size(8.5 * 96, 11 * 96),
				new Thickness(0.5 * 96), PageOrientation.Portrait);

			FixedDocumentRenderTarget renderTarget = new FixedDocumentRenderTarget();
			layout.RenderAllPages(renderTarget);

			viewer.Document = renderTarget.Document;
		}
	}
}
